@@ -13,25 +13,27 @@
 # License: GNU General Public License version 2 (June, 1991) or later #
 #                                                                     #
 #######################################################################
+##'@export
 haldane <-
 function(rcmb) {
   # rcmb must be a number between 0 and 0.5
   if (is.numeric(rcmb)) {
-    if (rcmb >= 0 && rcmb <= 0.5)
+    if (all(rcmb >= 0) & all(rcmb <= 0.5)){
       return(100*-(1/2)*log(1-2*rcmb))  # haldane mapping fuction
-    else stop("the recombination fraction must be between 0 and 0.5")
+    } else {stop("the recombination fraction must be between 0 and 0.5")}
   }
   else stop("the argument to 'haldane' function must be ",
             dQuote("numeric"))
 }
 
+##'@export
 kosambi <-
 function(rcmb) {
   # rcmb must be a number between 0 and 0.5
   if (is.numeric(rcmb)) {
-    if (rcmb >= 0 && rcmb <= 0.5)
+    if (all(rcmb >= 0) && all(rcmb <= 0.5)){
       return(100/4*log(abs((1+2*rcmb)/(1-2*rcmb))))  # kosambi mapping fuction
-    else stop("the recombination fraction must be between 0 and 0.5")
+    }else {stop("the recombination fraction must be between 0 and 0.5")}
   }
   else stop("the argument to 'kosambi' function must be ",
             dQuote("numeric"))
@@ -56,6 +58,7 @@ function(rcmb) {
 ##' Kosambi, D. D. (1944) The estimation of map distance from recombination
 ##' values. \emph{Annuaire of Eugenetics} 12: 172-175.
 ##' @keywords arith
+##' @export
 set_map_fun<-
   function(type=c("kosambi", "haldane")){
     type<-match.arg(type,c("kosambi", "haldane"))
