@@ -59,19 +59,19 @@
 ##'@export
 rf_2pts <- function(input.obj, LOD=3, max.rf=0.50, verbose = TRUE) {
     ## checking for correct object
-    if(!any(c("onemap", "outcross", "f2", "backcross", "riself", "risib") %in% class(input.obj)))
+    if(!is(input.obj, c("onemap", "outcross", "f2", "backcross", "riself", "risib")))
         stop(deparse(substitute(input.obj))," is not an object of class 'onemap'.")
     if (input.obj$n.mar<2) stop("there must be at least two markers to proceed with analysis")
     ## creating variables (result storage and progress output)
-    if(("outcross" %in% class(input.obj)))
+    if(is(input.obj,"outcross"))
         r<-est_rf_out(geno = input.obj$geno, seg_type = input.obj$segr.type.num, nind = input.obj$n.ind, verbose = verbose)
-    else if(("f2" %in% class(input.obj)))
+    else if(is(input.obj, "f2"))
         r<-est_rf_f2(geno = input.obj$geno, seg_type = input.obj$segr.type.num, nind = input.obj$n.ind, verbose = verbose)
-    else if(("backcross" %in% class(input.obj)))
+    else if(is(input.obj,"backcross"))
         r<-est_rf_bc(geno = input.obj$geno, nind = input.obj$n.ind, type=0, verbose = verbose)
-    else if(("riself" %in% class(input.obj)))
+    else if(is(input.obj,"riself"))
         r<-est_rf_bc(geno = input.obj$geno, nind = input.obj$n.ind, type=1, verbose = verbose)
-    else if(("risib" %in% class(input.obj)))
+    else if(is(input.obj, "risib"))
         r<-est_rf_bc(geno = input.obj$geno, nind = input.obj$n.ind, type=2, verbose = verbose)
         
     structure(list(data.name=as.character(sys.call())[2], n.mar=input.obj$n.mar, LOD=LOD, max.rf=max.rf,
