@@ -76,15 +76,15 @@
 ##'@export
 write_map<-function(map.list,file.out){
    # checking for correct object
-  if(!any(class(map.list)=="list" | class(map.list)=="sequence")) stop(deparse(substitute(map.list))," is not an object of class 'list' or 'sequnece'")
-  if(!any(class(file.out)=="character")) stop(deparse(substitute(file.out))," is an invalid output file name")
+  if(!(is(map.list,"list") | is(map.list,"sequence"))) stop(deparse(substitute(map.list))," is not an object of class 'list' or 'sequnece'")
+  if(!is(file.out,"character")) stop(deparse(substitute(file.out))," is an invalid output file name")
 
   # if map.list is just a single chormosome, convert it  into a list
-  if(class(map.list)=="sequence") map.list<-list(map.list)
+  if(is(map.list,"sequence")) map.list<-list(map.list)
 
   write(x="",file=file.out)
   for(i in 1:length(map.list)){
-    if(!any(class(map.list[[i]])=="sequence")) stop("Object ", i , " in map.list is not an object of class 'sequnece'")
+    if(!is(map.list[[i]],"sequence")) stop("Object ", i , " in map.list is not an object of class 'sequnece'")
     if(is.null(map.list[[i]]$seq.like))  stop("Parameters are not estimated for object ", i, " in map.list")
     map<-cumsum(c(0,get(get(".map.fun", envir=.onemapEnv))(map.list[[i]]$seq.rf)))
     marnames<-colnames(get(map.list[[i]]$data.name, pos=1)$geno)[map.list[[i]]$seq.num]
